@@ -1,6 +1,6 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from jsonrpc import Fault
+from .jsonrpc import Fault
 
 TrytonServerError = Fault
 
