@@ -1,17 +1,19 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import csv
+import datetime
 import os
 import tempfile
-import types
-
-import gtk
-import gobject
 import gettext
+import locale
+from numbers import Number
+
+from gi.repository import Gdk, GObject, Gtk
 
 import tryton.common as common
 from tryton.common import RPCExecute, RPCException
 from tryton.gui.window.win_csv import WinCSV
+from tryton.rpc import clear_cache
 
 _ = gettext.gettext
 
@@ -19,82 +21,82 @@ _ = gettext.gettext
 class WinExport(WinCSV):
     "Window export"
 
-    def __init__(self, model, ids, context=None):
+    def __init__(self, name, model, ids, context=None):
+        self.name = name
         self.ids = ids
         self.model = model
         self.context = context
         self.fields = {}
         super(WinExport, self).__init__()
-        self.dialog.set_title(_('Export to CSV'))
+        self.dialog.set_title(_('CSV Export: %s') % name)
 
-    def add_header(self, box):
-        frame_predef_exports = gtk.Frame()
+    def add_buttons(self, box):
+        button_save_export = Gtk.Button(
+            label=_('_Save Export'), stock=None, use_underline=True)
+        button_save_export.set_image(common.IconFactory.get_image(
+                'tryton-save', Gtk.IconSize.BUTTON))
+        button_save_export.set_always_show_image(True)
+        button_save_export.connect_after('clicked', self.addreplace_predef)
+        box.pack_start(
+            button_save_export, expand=False, fill=False, padding=0)
+
+        button_del_export = Gtk.Button(
+            label=_('_Delete Export'), stock=None, use_underline=True)
+        button_del_export.set_image(common.IconFactory.get_image(
+                'tryton-delete', Gtk.IconSize.BUTTON))
+        button_del_export.set_always_show_image(True)
+        button_del_export.connect_after('clicked', self.remove_predef)
+        box.pack_start(button_del_export, expand=False, fill=False, padding=0)
+
+        frame_predef_exports = Gtk.Frame()
         frame_predef_exports.set_border_width(2)
-        frame_predef_exports.set_shadow_type(gtk.SHADOW_NONE)
-        box.pack_start(frame_predef_exports, True, True, 0)
-        viewport_exports = gtk.Viewport()
-        scrolledwindow_exports = gtk.ScrolledWindow()
-        scrolledwindow_exports.set_policy(gtk.POLICY_AUTOMATIC,
-                gtk.POLICY_AUTOMATIC)
-        label_predef_exports = gtk.Label(_("<b>Predefined exports</b>"))
-        label_predef_exports.set_use_markup(True)
+        frame_predef_exports.set_shadow_type(Gtk.ShadowType.NONE)
+        box.pack_start(frame_predef_exports, expand=True, fill=True, padding=0)
+        viewport_exports = Gtk.Viewport()
+        scrolledwindow_exports = Gtk.ScrolledWindow()
+        scrolledwindow_exports.set_policy(
+            Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
+        label_predef_exports = Gtk.Label(
+            label=_("<b>Predefined exports</b>"), use_markup=True)
         frame_predef_exports.set_label_widget(label_predef_exports)
         viewport_exports.add(scrolledwindow_exports)
         frame_predef_exports.add(viewport_exports)
 
-        self.pref_export = gtk.TreeView()
-        self.pref_export.append_column(gtk.TreeViewColumn(_('Name'),
-            gtk.CellRendererText(), text=2))
+        self.pref_export = Gtk.TreeView()
+        self.pref_export.append_column(
+            Gtk.TreeViewColumn(_('Name'), Gtk.CellRendererText(), text=2))
         scrolledwindow_exports.add(self.pref_export)
         self.pref_export.connect("button-press-event", self.export_click)
         self.pref_export.connect("key-press-event", self.export_keypress)
 
-        self.predef_model = gtk.ListStore(
-                gobject.TYPE_INT,
-                gobject.TYPE_PYOBJECT,
-                gobject.TYPE_STRING)
+        self.predef_model = Gtk.ListStore(
+                GObject.TYPE_INT,
+                GObject.TYPE_PYOBJECT,
+                GObject.TYPE_STRING)
         self.fill_predefwin()
 
-    def add_buttons(self, box):
-        button_save_export = gtk.Button(
-            _('_Save Export'), stock=None, use_underline=True)
-        button_save_export.set_alignment(0.0, 0.0)
-        img_button = gtk.Image()
-        img_button.set_from_stock('tryton-save', gtk.ICON_SIZE_BUTTON)
-        button_save_export.set_image(img_button)
-        button_save_export.connect_after('clicked', self.addreplace_predef)
-        box.pack_start(button_save_export, False, False, 0)
-
-        button_del_export = gtk.Button(
-            _('_Delete Export'), stock=None, use_underline=True)
-        button_del_export.set_alignment(0.0, 0.0)
-        img_button = gtk.Image()
-        img_button.set_from_stock('tryton-delete', gtk.ICON_SIZE_BUTTON)
-        button_del_export.set_image(img_button)
-        button_del_export.connect_after('clicked', self.remove_predef)
-        box.pack_start(button_del_export, False, False, 0)
-
     def add_chooser(self, box):
-        hbox_csv_export = gtk.HBox()
-        box.pack_start(hbox_csv_export, False, True, 0)
-        if hasattr(gtk, 'ComboBoxText'):
-            self.saveas = gtk.ComboBoxText()
-        else:
-            self.saveas = gtk.combo_box_new_text()
-        hbox_csv_export.pack_start(self.saveas, True, True, 0)
+        hbox_csv_export = Gtk.HBox()
+        box.pack_start(hbox_csv_export, expand=False, fill=True, padding=0)
+        self.saveas = Gtk.ComboBoxText()
+        hbox_csv_export.pack_start(
+            self.saveas, expand=True, fill=True, padding=0)
         self.saveas.append_text(_("Open"))
         self.saveas.append_text(_("Save"))
         self.saveas.set_active(0)
 
-    def add_csv_header_param(self, table):
-        self.add_field_names = gtk.CheckButton(_("Add _field names"))
+    def add_csv_header_param(self, box):
+        self.add_field_names = Gtk.CheckButton(label=_("Add field names"))
         self.add_field_names.set_active(True)
-        table.attach(self.add_field_names, 2, 4, 1, 2)
+        box.pack_start(
+            self.add_field_names, expand=False, fill=True, padding=0)
 
     def model_populate(self, fields, parent_node=None, prefix_field='',
             prefix_name=''):
-        key = lambda (n, f): f.get('string') or n
-        for name, field in sorted(fields.items(), key=key, reverse=True):
+
+        def key(n_f):
+            return n_f[1].get('string') or n_f[0]
+        for name, field in sorted(list(fields.items()), key=key, reverse=True):
 
             string_ = field['string'] or name
 
@@ -163,30 +165,18 @@ class WinExport(WinCSV):
 
     def fill_predefwin(self):
         try:
-            export_ids = RPCExecute('model', 'ir.export', 'search',
+            exports = RPCExecute(
+                'model', 'ir.export', 'search_read',
                 [('resource', '=', self.model)], 0, None, None,
+                ['name', 'export_fields.name'],
                 context=self.context)
         except RPCException:
             return
-        try:
-            exports = RPCExecute('model', 'ir.export', 'read', export_ids,
-                None, context=self.context)
-        except RPCException:
-            return
-        try:
-            lines = RPCExecute('model', 'ir.export.line', 'read',
-                sum((list(x['export_fields']) for x in exports), []), None,
-                context=self.context)
-        except RPCException:
-            return
-        id2lines = {}
-        for line in lines:
-            id2lines.setdefault(line['export'], []).append(line)
         for export in exports:
             self.predef_model.append((
-                export['id'],
-                [x['name'] for x in id2lines.get(export['id'], [])],
-                export['name']))
+                    export['id'],
+                    [f['name'] for f in export['export_fields.']],
+                    export['name']))
         self.pref_export.set_model(self.predef_model)
 
     def addreplace_predef(self, widget):
@@ -227,6 +217,7 @@ class WinExport(WinCSV):
                     context=self.context)
         except RPCException:
             return
+        clear_cache('model.%s.view_toolbar_get' % self.model)
         if iter_ is None:
             self.predef_model.append((new_id, fields, name))
         else:
@@ -246,6 +237,7 @@ class WinExport(WinCSV):
                 context=self.context)
         except RPCException:
             return
+        clear_cache('model.%s.view_toolbar_get' % self.model)
         for i in range(len(self.predef_model)):
             if self.predef_model[i][0] == export_id:
                 del self.predef_model[i]
@@ -281,7 +273,7 @@ class WinExport(WinCSV):
         self.model2.append((long_string, name))
 
     def response(self, dialog, response):
-        if response == gtk.RESPONSE_OK:
+        if response == Gtk.ResponseType.OK:
             fields = []
             fields2 = []
             iter = self.model2.get_iter_first()
@@ -297,23 +289,25 @@ class WinExport(WinCSV):
                 data = []
 
             if action == 0:
-                fileno, fname = tempfile.mkstemp('.csv', 'tryton_')
+                fileno, fname = tempfile.mkstemp(
+                    '.csv', common.slugify(self.name) + '_')
                 self.export_csv(fname, fields2, data, popup=False)
                 os.close(fileno)
                 common.file_open(fname, 'csv')
             else:
                 fname = common.file_selection(_('Save As...'),
-                        action=gtk.FILE_CHOOSER_ACTION_SAVE)
+                        action=Gtk.FileChooserAction.SAVE)
                 if fname:
                     self.export_csv(fname, fields2, data)
         self.destroy()
 
     def export_csv(self, fname, fields, data, popup=True):
         encoding = self.csv_enc.get_active_text() or 'UTF-8'
+        locale_format = self.csv_locale.get_active()
 
         try:
             writer = csv.writer(
-                open(fname, 'wb+'),
+                open(fname, 'w', encoding=encoding, newline=''),
                 quotechar=self.get_quotechar(),
                 delimiter=self.get_delimiter())
             if self.add_field_names.get_active():
@@ -321,9 +315,15 @@ class WinExport(WinCSV):
             for line in data:
                 row = []
                 for val in line:
-                    if isinstance(type(val), types.StringType):
-                        val = val.replace('\n', ' ').replace('\t', ' ')
-                        val = val.encode(encoding)
+                    if locale_format:
+                        if isinstance(val, Number):
+                            val = locale.str(val)
+                        elif isinstance(val, datetime.datetime):
+                            val = val.strftime(common.date_format() + ' %X')
+                        elif isinstance(val, datetime.date):
+                            val = val.strftime(common.date_format())
+                    elif isinstance(val, bool):
+                        val = int(val)
                     row.append(val)
                 writer.writerow(row)
             if popup:
@@ -332,7 +332,7 @@ class WinExport(WinCSV):
                 else:
                     common.message(_('%d records saved.') % len(data))
             return True
-        except IOError, exception:
+        except IOError as exception:
             common.warning(_("Operation failed.\nError message:\n%s")
                 % exception, _('Error'))
             return False
@@ -343,7 +343,7 @@ class WinExport(WinCSV):
             return
         path, col, x, y = path_at_pos
         selection = treeview.get_selection()
-        if event.type == gtk.gdk._2BUTTON_PRESS:
+        if event.type == Gdk.EventType._2BUTTON_PRESS:
             self.sel_predef(path)
             selection.select_path(path)
             return True
@@ -352,7 +352,7 @@ class WinExport(WinCSV):
             return True
 
     def export_keypress(self, treeview, event):
-        if event.keyval not in (gtk.keysyms.Return, gtk.keysyms.space):
+        if event.keyval not in [Gdk.KEY_Return, Gdk.KEY_.space]:
             return
         model, selected = treeview.get_selection().get_selected()
         if not selected:
